@@ -5,26 +5,36 @@ set -o errexit
 
 ###
 # BallisticNG
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241230.1
+script_version=20250506.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='ballisticng'
 GAME_NAME='BallisticNG'
 
+ARCHIVE_BASE_1_NAME='ballisticng_1_4_0_1_81860.sh'
+ARCHIVE_BASE_1_MD5='beedfb6afab94fc66783c12b805876df'
+ARCHIVE_BASE_1_SIZE='3380551'
+ARCHIVE_BASE_1_VERSION='1.4.0.1-gog81860'
+ARCHIVE_BASE_1_URL='https://www.gog.com/game/ballisticng'
+
 ARCHIVE_BASE_0_NAME='ballisticng_1_3_3_1_69502.sh'
 ARCHIVE_BASE_0_MD5='4fd3dd5695e9f94523bb699df024dbee'
 ARCHIVE_BASE_0_SIZE='2749158'
 ARCHIVE_BASE_0_VERSION='1.3.3.1-gog69502'
-ARCHIVE_BASE_0_URL='https://www.gog.com/game/ballisticng'
 
 UNITY3D_NAME='BallisticNG'
 UNITY3D_PLUGINS='
 cimgui.so
 libaudioplugin_phonon.so
 libphonon.so'
+## Starting with game version 1.4,
+## the game no longer loads without the shipped Steam library.
+UNITY3D_PLUGINS="$UNITY3D_PLUGINS
+libsteam_api.so"
 
 CONTENT_PATH_DEFAULT='data/noarch/game'
 CONTENT_GAME0_BIN_FILES='
