@@ -2,16 +2,17 @@
 # SPDX-License-Identifier: BSD-2-Clause
 # SPDX-FileCopyrightText: © 2016 Antoine Le Gonidec <vv221@dotslashplay.it>
 # SPDX-FileCopyrightText: © 2017 Mopi
-# SPDX-FileCopyrightText: © 2020 Hoël Bézier
+# SPDX-FileCopyrightText: © 2020 Hoël Bézier <hoelbezier@riseup.net>
 set -o errexit
 
 ###
 # Bastion
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241027.1
+script_version=20250429.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='bastion'
 GAME_NAME='Bastion'
@@ -115,10 +116,9 @@ System.Xml.dll
 System.Xml.Linq.dll'
 
 PKG_LIBS_ID="${GAME_ID}-libs"
-PKG_LIBS64_ID="$PKG_LIBS_ID"
-PKG_LIBS32_ID="$PKG_LIBS_ID"
 PKG_LIBS64_ARCH='64'
 PKG_LIBS32_ARCH='32'
+## FIXME: Add the list of required system libraries
 
 # Load common functions
 
