@@ -5,11 +5,12 @@ set -o errexit
 
 ###
 # Dungeon Keeper 1
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241123.1
+script_version=20250722.2
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='dungeon-keeper-1'
 GAME_NAME='Dungeon Keeper'
@@ -33,10 +34,6 @@ ARCHIVE_BASE_0_TYPE='innosetup'
 ARCHIVE_BASE_0_SIZE='400000'
 ARCHIVE_BASE_0_VERSION='1.01-gog2.1.0.7'
 
-# Archives content
-
-## Main game content
-
 CONTENT_PATH_DEFAULT='.'
 CONTENT_PATH_DEFAULT_0='app'
 CONTENT_GAME_MAIN_FILES='
@@ -55,55 +52,40 @@ patch1.exe
 keeper.pat
 keeper.pti
 *.ogg'
-## In the 2.1.0.7 GOG installer, the disk image table of contents is named "game.inst" instead of "game.ins"
+CONTENT_GAME0_MAIN_PATH='__support/save'
+CONTENT_GAME0_MAIN_PATH_0='app'
 CONTENT_GAME0_MAIN_FILES='
-game.inst'
-CONTENT_GAME1_MAIN_PATH='__support/save'
-CONTENT_GAME1_MAIN_PATH_0='app'
-CONTENT_GAME1_MAIN_FILES='
 keeper.cfg
 sound/dig.ini'
 CONTENT_DOC_MAIN_FILES='
 readme.txt
 *.pdf'
-
-## Localizations
-
+## Localisation files, extracted from the disk image.
 CONTENT_L10N_TXT_PATH='keeper/data'
-CONTENT_L10N_VOICES_SPEECH_PATH='keeper/sound/speech'
-CONTENT_L10N_VOICES_ATLAS_PATH='keeper/sound/atlas'
-
-### English
-
 CONTENT_L10N_TXT_EN_PATH="${CONTENT_L10N_TXT_PATH}/english"
-CONTENT_L10N_TXT_EN_FILES='
-dd1text.dat
-text.dat'
-CONTENT_L10N_VOICES_SPEECH_EN_PATH="${CONTENT_L10N_VOICES_SPEECH_PATH}/english"
-CONTENT_L10N_VOICES_SPEECH_EN_FILES='
-speech.dat'
-CONTENT_L10N_VOICES_ATLAS_EN_PATH="${CONTENT_L10N_VOICES_ATLAS_PATH}/english"
-CONTENT_L10N_VOICES_ATLAS_EN_FILES='
-bad??.wav
-good??.wav'
-
-### French
-
 CONTENT_L10N_TXT_FR_PATH="${CONTENT_L10N_TXT_PATH}/french"
-CONTENT_L10N_TXT_FR_FILES='
+CONTENT_L10N_TXT_FILES='
 dd1text.dat
 text.dat'
+CONTENT_L10N_TXT_EN_FILES="$CONTENT_L10N_TXT_FILES"
+CONTENT_L10N_TXT_FR_FILES="$CONTENT_L10N_TXT_FILES"
+CONTENT_L10N_VOICES_SPEECH_PATH='keeper/sound/speech'
+CONTENT_L10N_VOICES_SPEECH_EN_PATH="${CONTENT_L10N_VOICES_SPEECH_PATH}/english"
 CONTENT_L10N_VOICES_SPEECH_FR_PATH="${CONTENT_L10N_VOICES_SPEECH_PATH}/french"
-CONTENT_L10N_VOICES_SPEECH_FR_FILES='
+CONTENT_L10N_VOICES_SPEECH_FILES='
 speech.dat'
+CONTENT_L10N_VOICES_SPEECH_EN_FILES="$CONTENT_L10N_VOICES_SPEECH_FILES"
+CONTENT_L10N_VOICES_SPEECH_FR_FILES="$CONTENT_L10N_VOICES_SPEECH_FILES"
+CONTENT_L10N_VOICES_ATLAS_PATH='keeper/sound/atlas'
+CONTENT_L10N_VOICES_ATLAS_EN_PATH="${CONTENT_L10N_VOICES_ATLAS_PATH}/english"
 CONTENT_L10N_VOICES_ATLAS_FR_PATH="${CONTENT_L10N_VOICES_ATLAS_PATH}/french"
-CONTENT_L10N_VOICES_ATLAS_FR_FILES='
+CONTENT_L10N_VOICES_ATLAS_FILES='
 bad??.wav
 good??.wav'
+CONTENT_L10N_VOICES_ATLAS_EN_FILES="$CONTENT_L10N_VOICES_ATLAS_FILES"
+CONTENT_L10N_VOICES_ATLAS_FR_FILES="$CONTENT_L10N_VOICES_ATLAS_FILES"
 
-
-GAME_IMAGE='game.ins'
-GAME_IMAGE_TYPE='iso'
+DOSBOX_DISK_IMAGE_PATH='game.ins'
 
 USER_PERSISTENT_DIRECTORIES='
 save'
@@ -150,12 +132,12 @@ PKG_L10N_VOICES_FR_PROVIDES="$PKG_L10N_VOICES_PROVIDES"
 PKG_L10N_VOICES_EN_DESCRIPTION='English voices'
 PKG_L10N_VOICES_FR_DESCRIPTION='French voices'
 
-# unar is used to extract the contents of the disk image
+# unar is used to extract files from the disk image.
 
 REQUIREMENTS_LIST="${REQUIREMENTS_LIST:-}
 unar"
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -181,32 +163,30 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
 	## Delete files that should not be included in the base package.
-	## These files are provided by the localization packages.
+	## These files are provided by localisation packages.
 	rm --force --recursive \
 		'data/dd1text.dat' \
 		'data/text.dat' \
 		'sound/atlas' \
 		'sound/speech.dat'
 
-	## Enforce a consistent name for the disk image table of content.
-	## TODO: This would not be required if the DISK_IMAGE variable was context-sensitive
-	##       cf. https://forge.dotslashplay.it/play.it/play.it/-/issues/549
+	## Enforce consistent name for the disk image table of content.
 	if [ -e 'game.inst' ]; then
-		mv 'game.inst' "$GAME_IMAGE"
+		mv 'game.inst' "$(dosbox_disk_image_path)"
 	fi
 )
-# Extract localization content from the disk image
+## Extract localisation files from the disk image.
 ARCHIVE_L10N_PATH="${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/game.gog"
 ARCHIVE_L10N_EXTRACTOR='unar'
 archive_extraction 'ARCHIVE_L10N'
@@ -217,7 +197,7 @@ archive_extraction 'ARCHIVE_L10N'
 	tolower .
 )
 
-# Include game data
+# Include game data.
 
 content_inclusion_icons 'PKG_MAIN'
 content_inclusion 'L10N_TXT_EN' 'PKG_L10N_TXT_EN' "$(path_game_data)/data"
@@ -228,11 +208,11 @@ content_inclusion 'L10N_VOICES_ATLAS_EN' 'PKG_L10N_VOICES_EN' "$(path_game_data)
 content_inclusion 'L10N_VOICES_ATLAS_FR' 'PKG_L10N_VOICES_FR' "$(path_game_data)/sound/atlas"
 content_inclusion_default
 
-# Write launchers
+# Write launchers.
 
 launchers_generation 'PKG_MAIN'
 
-# Build packages
+# Build packages.
 
 packages_generation
 case "$(messages_language)" in
@@ -253,7 +233,7 @@ print_instructions 'PKG_L10N_TXT_EN' 'PKG_L10N_VOICES_EN' 'PKG_MAIN'
 printf "$lang_string" "$lang_fr"
 print_instructions 'PKG_L10N_TXT_FR' 'PKG_L10N_VOICES_FR' 'PKG_MAIN'
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
