@@ -7,11 +7,12 @@ set -o errexit
 
 ###
 # Faster Than Light
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241027.1
+script_version=20250429.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='faster-than-light'
 GAME_NAME='FTL: Faster Than Light'
@@ -109,8 +110,6 @@ PKG_BIN64_ARCH='64'
 PKG_BIN32_ARCH='32'
 PKG_BIN_DEPENDENCIES_SIBLINGS='
 PKG_DATA'
-PKG_BIN64_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
-PKG_BIN32_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libasound.so.2
 libc.so.6
@@ -120,8 +119,6 @@ libm.so.6
 libpthread.so.0
 librt.so.1
 libX11.so.6'
-PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
-PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
