@@ -10,11 +10,12 @@ set -o errexit
 # - Baldur's Gate 2 Enhanced Edition
 # - Icewind Dale 1 Enhanced Edition
 # - Planescape: Torment Enhanced Edition
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250227.1
+script_version=20250721.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID_BG1='baldurs-gate-1-enhanced-edition'
 GAME_NAME_BG1='Baldurʼs Gate Enhanced Edition'
@@ -32,11 +33,16 @@ GAME_NAME_PST='Planescape: Torment Enhanced Edition'
 
 ## Baldur's Gate 1 Enhanced Edition
 
+ARCHIVE_BASE_BG1_2_NAME='baldur_s_gate_enhanced_edition_2_6_6_0_p_81762.sh'
+ARCHIVE_BASE_BG1_2_MD5='69a65780f1fe8292e47e922f9b16a4be'
+ARCHIVE_BASE_BG1_2_SIZE='3263827'
+ARCHIVE_BASE_BG1_2_VERSION='2.6.6.0-gog81762'
+ARCHIVE_BASE_BG1_2_URL='https://www.gog.com/game/baldurs_gate_enhanced_edition'
+
 ARCHIVE_BASE_BG1_1_NAME='baldur_s_gate_enhanced_edition_2_6_6_0_47291.sh'
 ARCHIVE_BASE_BG1_1_MD5='6f7be163ebb80a0fbc9d6331f9c6f09c'
 ARCHIVE_BASE_BG1_1_SIZE='3300000'
 ARCHIVE_BASE_BG1_1_VERSION='2.6.6.0-gog47291'
-ARCHIVE_BASE_BG1_1_URL='https://www.gog.com/game/baldurs_gate_enhanced_edition'
 
 ARCHIVE_BASE_BG1_0_NAME='baldur_s_gate_enhanced_edition_2_6_5_0_46477.sh'
 ARCHIVE_BASE_BG1_0_MD5='a87444f36602b5059e3c885ec2ff50e1'
@@ -59,11 +65,16 @@ CONTENT_ICONS_FILES_BG1='
 
 ## Baldur's Gate 2 Enhanced Edition
 
+ARCHIVE_BASE_BG2_2_NAME='baldur_s_gate_ii_enhanced_edition_2_6_6_0_p_81762.sh'
+ARCHIVE_BASE_BG2_2_MD5='55a058ab9fbc40f78ce1d89bac7370a0'
+ARCHIVE_BASE_BG2_2_SIZE='3721955'
+ARCHIVE_BASE_BG2_2_VERSION='2.6.6.0-gog81762'
+ARCHIVE_BASE_BG2_2_URL='https://www.gog.com/game/baldurs_gate_2_enhanced_edition'
+
 ARCHIVE_BASE_BG2_1_NAME='baldur_s_gate_ii_enhanced_edition_2_6_6_0_47292.sh'
 ARCHIVE_BASE_BG2_1_MD5='43b37a554ffb712176ea8709fc98ed84'
 ARCHIVE_BASE_BG2_1_SIZE='380000'
 ARCHIVE_BASE_BG2_1_VERSION='2.6.6.0-gog47292'
-ARCHIVE_BASE_BG2_1_URL='https://www.gog.com/game/baldurs_gate_2_enhanced_edition'
 
 ARCHIVE_BASE_BG2_0_NAME='baldur_s_gate_ii_enhanced_edition_2_6_5_0_46477.sh'
 ARCHIVE_BASE_BG2_0_MD5='aa62efd4b1c69f074a784e637234e7c4'
@@ -163,16 +174,28 @@ data'
 ## so they can be used as a fallback for incomplete localizations.
 CONTENT_GAME0_DATA_FILES='
 lang/en_US'
-CONTENT_DOC_DATA_RELATIVE_PATH='../docs'
-## FIXME: An explicit list of files should be set.
-CONTENT_DOC_DATA_FILES='
-*'
 
 APP_MAIN_EXE_BG1='BaldursGate'
 APP_MAIN_EXE_BG2='BaldursGateII'
 APP_MAIN_EXE_IWD1='IcewindDale'
 APP_MAIN_EXE_PST='Torment64'
 APP_MAIN_ICON='../support/icon.png'
+## Trying to run the game with the wayland SDL backend leads to a segmentation fault:
+##
+## #0  0x00005555558d999f in DrawInit_GL(void*) ()
+## #1  0x00005555559188ee in CVidMode::SetDisplayMode() ()
+## #2  0x00005555558f9585 in CChitin::InitializeServices() ()
+## #3  0x00005555558fd75d in CChitin::WinMain() ()
+## #4  0x00005555554988d8 in main ()
+##
+## Forcing the use of system-provided SDL does not avoid this crash.
+APP_MAIN_PRERUN='
+# Trying to run the game with the wayland SDL backend leads to a segmentation fault
+if [ "${SDL_VIDEODRIVER:-}" = "wayland" ]; then
+	unset SDL_VIDEODRIVER
+fi
+'
+
 
 # Packages
 
@@ -194,7 +217,6 @@ libm.so.6
 libopenal.so.1
 libpthread.so.0
 librt.so.1
-libSDL2-2.0.so.0
 libssl.so.1.0.0
 libstdc++.so.6
 libX11.so.6'
@@ -202,7 +224,6 @@ libX11.so.6'
 PKG_L10N_FR_DESCRIPTION='French localization'
 PKG_L10N_DEPENDENCIES_SIBLINGS='
 PKG_BIN'
-PKG_L10N_FR_DEPENDENCIES_SIBLINGS="$PKG_L10N_DEPENDENCIES_SIBLINGS"
 
 PKG_DATA_DESCRIPTION='data'
 
@@ -212,7 +233,6 @@ PKG_L10N_ID_BG1="${GAME_ID_BG1}-l10n"
 PKG_L10N_FR_ID_BG1="${PKG_L10N_ID_BG1}-fr"
 PKG_L10N_PROVIDES_BG1="
 $PKG_L10N_ID_BG1"
-PKG_L10N_FR_PROVIDES_BG1="$PKG_L10N_PROVIDES_BG1"
 
 PKG_DATA_ID_BG1="${GAME_ID_BG1}-data"
 ## Ensure easy upgrades from packaged generated with pre-20250103.1 game scripts
@@ -225,7 +245,6 @@ PKG_L10N_ID_BG2="${GAME_ID_BG2}-l10n"
 PKG_L10N_FR_ID_BG2="${PKG_L10N_ID_BG2}-fr"
 PKG_L10N_PROVIDES_BG2="
 $PKG_L10N_ID_BG2"
-PKG_L10N_FR_PROVIDES_BG2="$PKG_L10N_PROVIDES_BG2"
 
 PKG_DATA_ID_BG2="${GAME_ID_BG2}-data"
 ## Ensure easy upgrades from packaged generated with pre-20250103.1 game scripts
@@ -238,7 +257,6 @@ PKG_L10N_ID_IWD1="${GAME_ID_IWD1}-l10n"
 PKG_L10N_FR_ID_IWD1="${PKG_L10N_ID_IWD1}-fr"
 PKG_L10N_PROVIDES_IWD1="
 $PKG_L10N_ID_IWD1"
-PKG_L10N_FR_PROVIDES_IWD1="$PKG_L10N_PROVIDES_IWD1"
 
 PKG_DATA_ID_IWD1="${GAME_ID_IWD1}-data"
 ## Ensure easy upgrades from packaged generated with pre-20250103.1 game scripts
@@ -251,7 +269,6 @@ PKG_L10N_ID_PST="${GAME_ID_PST}-l10n"
 PKG_L10N_FR_ID_PST="${PKG_L10N_ID_PST}-fr"
 PKG_L10N_PROVIDES_PST="
 $PKG_L10N_ID_PST"
-PKG_L10N_FR_PROVIDES_PST="$PKG_L10N_PROVIDES_PST"
 
 PKG_DATA_ID_PST="${GAME_ID_PST}-data"
 ## Ensure easy upgrades from packaged generated with pre-20250103.1 game scripts
@@ -302,15 +319,8 @@ content_inclusion_default
 ## Force the use of system-provided SDL
 APP_MAIN_PRERUN="$(application_prerun 'APP_MAIN')
 $(launcher_tweak_sdl_override)"
-
-## The game segfaults on launch when SDL_VIDEODRIVER is set to "wayland".
-## Forcing the use of system-provided SDL with SDL_DYNAMIC_API does not help.
-APP_MAIN_PRERUN="$(application_prerun 'APP_MAIN')"'
-# The game segfaults on launch when SDL_VIDEODRIVER is set to "wayland".
-if [ "${SDL_VIDEODRIVER:-}" = "wayland" ]; then
-	unset SDL_VIDEODRIVER
-fi
-'
+PKG_BIN_DEPENDENCIES_LIBRARIES="$(dependencies_list_native_libraries 'PKG_BIN')
+libSDL2-2.0.so.0"
 
 launchers_generation 'PKG_BIN'
 
