@@ -10,11 +10,12 @@ set -o errexit
 # - Icewind Dale 1
 # - Icewind Dale 2
 # - Planescape: Torment
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241121.6
+script_version=20250611.2
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID_BG1='baldurs-gate-1'
 GAME_NAME_BG1='Baldurʼs Gate'
@@ -163,125 +164,223 @@ ARCHIVE_BASE_PST_RU_0_MD5='d6fd52fe9946bcc067eed441945127f1'
 ARCHIVE_BASE_PST_RU_0_SIZE='2400000'
 ARCHIVE_BASE_PST_RU_0_VERSION='1.1-gog2.2.0.10'
 
+# Archives content
+
+## Baldur's Gate
 
 CONTENT_PATH_DEFAULT_BG1_EN="data/noarch/prefix/drive_c/GOG Games/Baldur's Gate"
 CONTENT_PATH_DEFAULT_BG1_FR="data/noarch/prefix/drive_c/GOG Games/Baldur's Gate (French)"
 CONTENT_PATH_DEFAULT_BG1_PL="data/noarch/prefix/drive_c/GOG Games/Baldur's Gate (Polish)"
-CONTENT_PATH_DEFAULT_BG2_EN="data/noarch/prefix/drive_c/GOG Games/Baldur's Gate 2"
-CONTENT_PATH_DEFAULT_BG2_FR="data/noarch/prefix/drive_c/GOG Games/Baldur's Gate 2 (French)"
-CONTENT_PATH_DEFAULT_IWD1='app'
-CONTENT_PATH_DEFAULT_IWD2='.'
-CONTENT_PATH_DEFAULT_IWD2_EN_0='app'
-CONTENT_PATH_DEFAULT_IWD2_FR_0='app'
-CONTENT_PATH_DEFAULT_PST_EN='data/noarch/prefix/drive_c/GOG Games/Planescape Torment'
-CONTENT_PATH_DEFAULT_PST_RU='data/noarch/prefix/drive_c/GOG Games/Planescape Torment (Russian)'
-CONTENT_PATH_DEFAULT_PST_FR='data/noarch/prefix/drive_c/GOG Games/Planescape Torment (French)'
-## TODO: Game-specific lists would be easier to review
-CONTENT_GAME_BIN_FILES='
-script compiler
+CONTENT_GAME_BIN_FILES_BG1='
 luaauto.cfg
-lasnil32.dll
-3dfx.dll
-binkw32.dll
 baldur.exe
-bgdxtest.exe
-bggltest.exe
-bcgonfig.exe
-bgmain.exe
 bgmain2.exe
-charview.exe
+bgmain.exe
 config.exe
-glsetup.exe
-idmain.exe
-iwd2.exe
 mconvert.exe
-mplaynow.exe
-torment.exe
-autonote.ini
-beast.ini
-keymap.ini
-layout.ini
-quests.ini'
-CONTENT_GAME0_BIN_RELATIVE_PATH='__support/app'
-CONTENT_GAME0_BIN_FILES='
-iwd2.exe
 keymap.ini'
-## The following configuration files are generated by the current game script,
-## the shipped versions are ignored.
-CONTENT_GAME1_BIN_FILES='
-baldur.ini
-icewind.ini
-icewind2.ini
-torment.ini'
-CONTENT_GAME_L10N_FILES='
-cachemos.bif
-crefiles.bif
-cs_0404.bif
-interface.bif
-sound.bif
-voice.bif
-language.ini
-party.ini
-language.txt
+## The following configuration file is generated by the current game script,
+## the shipped version is ignored.
+CONTENT_GAME0_BIN_FILES_BG1='
+baldur.ini'
+CONTENT_GAME_L10N_FILES_BG1='
 characters
 override
 movies
 mpsave
 save
 sounds
-cd2/data/*.mve
-cd2/data/sndvo.bif
-data/*sound*.bif
+chitin.key
+dialog.tlk
+dialogf.tlk
+data/areas.bif
+data/objanim.bif
+data/scripts.bif
+data/*sound*.bif'
+CONTENT_GAME_DATA_FILES_BG1='
+data
+music
+scripts'
+CONTENT_DOC_L10N_PATH_BG1_EN='data/noarch/docs/english'
+CONTENT_DOC_L10N_PATH_BG1_FR='data/noarch/docs/french'
+CONTENT_DOC_L10N_PATH_BG1_PL='data/noarch/docs/polish'
+CONTENT_DOC_L10N_PATH_BG1_EN_0='data/noarch/docs'
+CONTENT_DOC_L10N_PATH_BG1_FR_0='data/noarch/docs'
+CONTENT_DOC_L10N_FILES_BG1='
+*.pdf
+*.txt'
+
+## Baldur's Gate 2
+
+CONTENT_PATH_DEFAULT_BG2_EN="data/noarch/prefix/drive_c/GOG Games/Baldur's Gate 2"
+CONTENT_PATH_DEFAULT_BG2_FR="data/noarch/prefix/drive_c/GOG Games/Baldur's Gate 2 (French)"
+CONTENT_GAME_BIN_FILES_BG2='
+script compiler
+lasnil32.dll
+baldur.exe
+bgconfig.exe
+bgdxtest.exe
+bggltest.exe
+bgmain.exe
+charview.exe
+glsetup.exe
+keymap.ini'
+## The following configuration file is generated by the current game script,
+## the shipped version is ignored.
+CONTENT_GAME0_BIN_FILES_BG2='
+baldur.ini'
+CONTENT_GAME_L10N_FILES_BG2='
+characters
+override
+sounds
+chitin.key
+dialog.tlk
+dialogf.tlk
+language.txt
+data/movies
 data/25npcso.bif
 data/areas.bif
-data/genmova.bif
-data/movies?.bif
-data/npcsocd?.bif
 data/npchd0so.bif
 data/objanim.bif
 data/scripts.bif
-data/movies
-*.key
-*.tlk'
-CONTENT_GAME0_L10N_RELATIVE_PATH='__support/app'
-CONTENT_GAME0_L10N_FILES='
-party.ini'
-CONTENT_GAME_DATA_FILES='
+data/npcsocd?.bif
+data/*sound*.bif'
+CONTENT_GAME_DATA_FILES_BG2='
+data
+music
+scripts
 baldur.ico
-var.var
+bgate2.mpi'
+CONTENT_DOC_L10N_PATH_BG2_EN='data/noarch/docs/english'
+CONTENT_DOC_L10N_PATH_BG2_FR='data/noarch/docs/french'
+CONTENT_DOC_L10N_PATH_BG2_EN_0='data/noarch/docs'
+CONTENT_DOC_L10N_PATH_BG2_FR_0='data/noarch/docs'
+CONTENT_DOC_L10N_FILES_BG2='
+*.pdf
+*.txt'
+
+## Icewind Dale
+
+CONTENT_PATH_DEFAULT_IWD1='app'
+CONTENT_GAME_BIN_FILES_IWD1='
+3dfx.dll
+config.exe
+glsetup.exe
+idmain.exe
+keymap.ini'
+## The following configuration file is generated by the current game script,
+## the shipped version is ignored.
+CONTENT_GAME0_BIN_FILES_IWD1='
+icewind.ini'
+CONTENT_GAME_L10N_FILES_IWD1='
+characters
+override
+mpsave
+sounds
+language.ini
+chitin.key
+dialog.tlk
+cd2/data/sndvo.bif'
+CONTENT_GAME_DATA_FILES_IWD1='
 cd2
 cd3
 data
 music
-scripts
-*.bif
-*.mpi'
-CONTENT_DOC_L10N_FILES='
-*.htm
+scripts'
+CONTENT_DOC_L10N_FILES_IWD1='
+manual.pdf
+patch_addon.txt
+patch_addon2.txt
+readme.txt
+readme_addon.txt
+readme_addon2.txt
+readme_eng.txt'
+
+## Icewind Dale 2
+
+CONTENT_PATH_DEFAULT_IWD2='.'
+CONTENT_PATH_DEFAULT_IWD2_EN_0='app'
+CONTENT_PATH_DEFAULT_IWD2_FR_0='app'
+CONTENT_GAME_BIN_FILES_IWD2='
+binkw32.dll
+config.exe
+iwd2.exe
+keymap.ini'
+## The following configuration file is generated by the current game script,
+## the shipped version is ignored.
+CONTENT_GAME0_BIN_FILES_IWD2='
+icewind2.ini'
+CONTENT_GAME1_BIN_RELATIVE_PATH_IWD2='__support/app'
+CONTENT_GAME1_BIN_FILES_IWD2='
+iwd2.exe
+keymap.ini'
+CONTENT_GAME_L10N_FILES_IWD2='
+characters
+override
+sounds
+language.ini
+party.ini
+chitin.key
+dialog.tlk
+dialogf.tlk
+cd2/data/sndvo.bif
+cd2/data/*.mve'
+CONTENT_GAME0_L10N_RELATIVE_PATH_IWD2='__support/app'
+CONTENT_GAME0_L10N_FILES_IWD2='
+party.ini'
+CONTENT_GAME_DATA_FILES_IWD2='
+cd2
+data
+music
+scripts'
+CONTENT_DOC_L10N_FILES_IWD2='
+readme.htm
+manual.pdf
+patch.txt'
+
+## Planescape: Torment
+
+CONTENT_PATH_DEFAULT_PST_EN='data/noarch/prefix/drive_c/GOG Games/Planescape Torment'
+CONTENT_PATH_DEFAULT_PST_RU='data/noarch/prefix/drive_c/GOG Games/Planescape Torment (Russian)'
+CONTENT_PATH_DEFAULT_PST_FR='data/noarch/prefix/drive_c/GOG Games/Planescape Torment (French)'
+CONTENT_GAME_BIN_FILES_PST='
+torment.exe
+autonote.ini
+beast.ini
+keymap.ini
+layout.ini
+quests.ini'
+## The following configuration file is generated by the current game script,
+## the shipped version is ignored.
+CONTENT_GAME0_BIN_FILES_PST='
+torment.ini'
+CONTENT_GAME_L10N_FILES_PST='
+override
+cachemos.bif
+crefiles.bif
+cs_0404.bif
+interface.bif
+sound.bif
+voice.bif
+chitin.key
+dialog.tlk
+dialogf.tlk
+data/genmova.bif
+data/movies?.bif'
+CONTENT_GAME_DATA_FILES_PST='
+data
+music
+var.var
+*.bif'
+CONTENT_DOC_L10N_PATH_PST_EN='data/noarch/docs/english'
+CONTENT_DOC_L10N_PATH_PST_FR='data/noarch/docs/french'
+CONTENT_DOC_L10N_PATH_PST_RU='data/noarch/docs/russian'
+CONTENT_DOC_L10N_PATH_PST_EN_0='data/noarch/docs'
+CONTENT_DOC_L10N_PATH_PST_FR_0='data/noarch/docs'
+CONTENT_DOC_L10N_PATH_PST_RU_0='data/noarch/docs'
+CONTENT_DOC_L10N_FILES_PST='
 *.pdf
 *.txt'
-CONTENT_DOC0_L10N_PATH_BG1_EN='data/noarch/docs/english'
-CONTENT_DOC0_L10N_PATH_BG1_FR='data/noarch/docs/french'
-CONTENT_DOC0_L10N_PATH_BG1_PL='data/noarch/docs/polish'
-CONTENT_DOC0_L10N_PATH_BG1_EN_0='data/noarch/docs'
-CONTENT_DOC0_L10N_PATH_BG1_FR_0='data/noarch/docs'
-CONTENT_DOC0_L10N_PATH_BG2_EN='data/noarch/docs/english'
-CONTENT_DOC0_L10N_PATH_BG2_FR='data/noarch/docs/french'
-CONTENT_DOC0_L10N_PATH_BG2_EN_0='data/noarch/docs'
-CONTENT_DOC0_L10N_PATH_BG2_FR_0='data/noarch/docs'
-CONTENT_DOC0_L10N_PATH_PST_EN='data/noarch/docs/english'
-CONTENT_DOC0_L10N_PATH_PST_FR='data/noarch/docs/french'
-CONTENT_DOC0_L10N_PATH_PST_RU='data/noarch/docs/russian'
-CONTENT_DOC0_L10N_PATH_PST_EN_0='data/noarch/docs'
-CONTENT_DOC0_L10N_PATH_PST_FR_0='data/noarch/docs'
-CONTENT_DOC0_L10N_PATH_PST_RU_0='data/noarch/docs'
-## FIXME: An explicit files list should be given.
-CONTENT_DOC0_L10N_FILES_BG1='
-*'
-CONTENT_DOC0_L10N_FILES_BG2='
-*'
-CONTENT_DOC0_L10N_FILES_PST='
-*'
 
 # Applications
 
@@ -313,12 +412,6 @@ APP_CONFIG_EXE_BG1='config.exe'
 
 APP_MAIN_EXE_BG2='bgmain.exe'
 APP_MAIN_ICON_BG2='baldur.exe'
-## Merge "data" and "data/data".
-## TODO: The symbolic link could probably be shipped in the package instead.
-APP_MAIN_PRERUN_BG2='
-# Merge "data" and "data/data"
-ln --symbolic --force --no-target-directory . "data/data"
-'
 
 APP_CONFIG_ID_BG2="${GAME_ID_BG2}-config"
 APP_CONFIG_NAME_BG2="$GAME_NAME_BG2 - configuration"
@@ -472,18 +565,21 @@ archive_extraction_default
 		tolower .
 	fi
 
-	## Baldur's Gate 2
-	## - Delete broken symbolic links
-	## - Merge "data" and "data/data"
+	# Baldur's Gate 2 - Delete broken symbolic links.
 	case "$(current_archive)" in
 		('ARCHIVE_BASE_BG2_'*)
 			rm --force --recursive \
 				'mpsave' \
 				'temp'
-			if [ -e 'data/data' ]; then
-				cp --link --recursive --update=none 'data/data/'* 'data/'
-				rm --force --recursive 'data/data'
-			fi
+		;;
+	esac
+
+	# Baldur's Gate 2 - Drop duplicated files.
+	case "$(current_archive)" in
+		('ARCHIVE_BASE_BG2_'*)
+			rm \
+				'data/data/cd3crean.bif' \
+				'data/data/cd4crea3.bif'
 		;;
 	esac
 
