@@ -6,9 +6,10 @@ set -o errexit
 
 ###
 # Slay the Princess
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250211.1
+script_version=20250331.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
@@ -20,11 +21,21 @@ GAME_NAME_DEMO="$GAME_NAME (demo)"
 
 ## The Pristine Cut
 
+ARCHIVE_BASE_18_NAME='slay_the_princess_the_pristine_cut_slay_the_princess_the_pristine_cut_march_5_linux_80450.sh'
+ARCHIVE_BASE_18_MD5='711ddf89d77c92c9d225a76a0917b2ca'
+ARCHIVE_BASE_18_SIZE='12719976'
+ARCHIVE_BASE_18_VERSION='1.4a-gog80450'
+ARCHIVE_BASE_18_URL='https://www.gog.com/game/slay_the_princess'
+
+ARCHIVE_BASE_17_NAME='slay_the_princess_the_pristine_cut_the_pristine_cut_linux_1_4a_80374.sh'
+ARCHIVE_BASE_17_MD5='3006483812c9d874039b59776a894b6f'
+ARCHIVE_BASE_17_SIZE='12720003'
+ARCHIVE_BASE_17_VERSION='1.4a-gog80374'
+
 ARCHIVE_BASE_16_NAME='slay_the_princess_the_pristine_cut_the_pristine_cut_linux_1_1a_79534.sh'
 ARCHIVE_BASE_16_MD5='4b7dfeb531a7431bbd2fe84e0fc2cfde'
 ARCHIVE_BASE_16_SIZE='12700851'
 ARCHIVE_BASE_16_VERSION='1.1a-gog79534'
-ARCHIVE_BASE_16_URL='https://www.gog.com/game/slay_the_princess'
 
 ARCHIVE_BASE_15_NAME='slay_the_princess_the_pristine_cut_the_pristine_cut_linux_1_0z_77466.sh'
 ARCHIVE_BASE_15_MD5='9492a8cffbf5ab5ac79593ceb763d072'
