@@ -8,11 +8,12 @@ set -o errexit
 # - Arachnoid Portrait Pack
 # - Horizon Signal
 # - Anniversary Portraits
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241215.1
+script_version=20250504.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='stellaris'
 GAME_NAME='Stellaris'
@@ -30,11 +31,16 @@ EXPANSION_NAME_ANNIVERSARY='Anniversary Portraits'
 
 ## Arachnoid Portrait Pack
 
+ARCHIVE_BASE_ARACHNOID_64_NAME='stellaris_arachnoid_portrait_pack_3_14_1592653_81105.sh'
+ARCHIVE_BASE_ARACHNOID_64_MD5='4168a3e72b2c19b0e7072e381b235314'
+ARCHIVE_BASE_ARACHNOID_64_SIZE='817'
+ARCHIVE_BASE_ARACHNOID_64_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_ARACHNOID_64_URL='https://www.gog.com/game/stellaris_galaxy_edition_upgrade_pack'
+
 ARCHIVE_BASE_ARACHNOID_63_NAME='stellaris_arachnoid_portrait_pack_3_14_15926_78464.sh'
 ARCHIVE_BASE_ARACHNOID_63_MD5='9da0b12f862958f4af43ae7612445adb'
 ARCHIVE_BASE_ARACHNOID_63_SIZE='817'
 ARCHIVE_BASE_ARACHNOID_63_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_ARACHNOID_63_URL='https://www.gog.com/game/stellaris_galaxy_edition_upgrade_pack'
 
 ARCHIVE_BASE_ARACHNOID_62_NAME='stellaris_arachnoid_portrait_pack_3_13_2_0_76713.sh'
 ARCHIVE_BASE_ARACHNOID_62_MD5='6584255df86295e64f59c6e9c1b69503'
@@ -108,11 +114,16 @@ ARCHIVE_BASE_ARACHNOID_22_VERSION='3.0.3-gog47193'
 
 ## Horizon Signal
 
+ARCHIVE_BASE_HORIZONSIGNAL_64_NAME='stellaris_horizon_signal_3_14_1592653_81105.sh'
+ARCHIVE_BASE_HORIZONSIGNAL_64_MD5='b5f000f1f6ab8e30cb90ffffcbb07716'
+ARCHIVE_BASE_HORIZONSIGNAL_64_SIZE='817'
+ARCHIVE_BASE_HORIZONSIGNAL_64_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_HORIZONSIGNAL_64_URL='https://www.gog.com/game/stellaris_horizon_signal'
+
 ARCHIVE_BASE_HORIZONSIGNAL_63_NAME='stellaris_horizon_signal_3_14_15926_78464.sh'
 ARCHIVE_BASE_HORIZONSIGNAL_63_MD5='2e1dd57ce9e7f96216b7afd9ac2ad81b'
 ARCHIVE_BASE_HORIZONSIGNAL_63_SIZE='817'
 ARCHIVE_BASE_HORIZONSIGNAL_63_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_HORIZONSIGNAL_63_URL='https://www.gog.com/game/stellaris_horizon_signal'
 
 ARCHIVE_BASE_HORIZONSIGNAL_62_NAME='stellaris_horizon_signal_3_13_2_0_76713.sh'
 ARCHIVE_BASE_HORIZONSIGNAL_62_MD5='9719994a74b4778c50a5a9a0a1390d4a'
