@@ -11,11 +11,12 @@ set -o errexit
 # - Necroids
 # - Aquatics
 # - Toxoids
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241215.1
+script_version=20250504.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='stellaris'
 GAME_NAME='Stellaris'
@@ -42,11 +43,16 @@ EXPANSION_NAME_TOXOIDS='Toxoids Species Pack'
 
 ## Plantoids
 
+ARCHIVE_BASE_PLANTOID_61_NAME='stellaris_plantoids_species_pack_3_14_1592653_81105.sh'
+ARCHIVE_BASE_PLANTOID_61_MD5='f2096d98d49833c1f900cd91b427b99d'
+ARCHIVE_BASE_PLANTOID_61_SIZE='837'
+ARCHIVE_BASE_PLANTOID_61_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_PLANTOID_61_URL='https://www.gog.com/game/stellaris_plantoids_species_pack'
+
 ARCHIVE_BASE_PLANTOID_60_NAME='stellaris_plantoids_species_pack_3_14_15926_78464.sh'
 ARCHIVE_BASE_PLANTOID_60_MD5='d35b66bc263d6111755f070bd9029832'
 ARCHIVE_BASE_PLANTOID_60_SIZE='837'
 ARCHIVE_BASE_PLANTOID_60_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_PLANTOID_60_URL='https://www.gog.com/game/stellaris_plantoids_species_pack'
 
 ARCHIVE_BASE_PLANTOID_59_NAME='stellaris_plantoids_species_pack_3_13_2_0_76713.sh'
 ARCHIVE_BASE_PLANTOID_59_MD5='3b5da3bbc12bef1778070cb48c0d5b5e'
@@ -125,11 +131,16 @@ ARCHIVE_BASE_PLANTOID_19_VERSION='3.0.3-gog47193'
 
 ## Humanoids
 
+ARCHIVE_BASE_HUMANOIDS_61_NAME='stellaris_humanoids_species_pack_3_14_1592653_81105.sh'
+ARCHIVE_BASE_HUMANOIDS_61_MD5='b0ca9dba864d8726f822b03749cc680c'
+ARCHIVE_BASE_HUMANOIDS_61_SIZE='84675'
+ARCHIVE_BASE_HUMANOIDS_61_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_HUMANOIDS_61_URL='https://www.gog.com/game/stellaris_humanoids_species_pack'
+
 ARCHIVE_BASE_HUMANOIDS_60_NAME='stellaris_humanoids_species_pack_3_14_15926_78464.sh'
 ARCHIVE_BASE_HUMANOIDS_60_MD5='783bfe3b3ddc324fc0b8d29b2e41a56a'
 ARCHIVE_BASE_HUMANOIDS_60_SIZE='84675'
 ARCHIVE_BASE_HUMANOIDS_60_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_HUMANOIDS_60_URL='https://www.gog.com/game/stellaris_humanoids_species_pack'
 
 ARCHIVE_BASE_HUMANOIDS_59_NAME='stellaris_humanoids_species_pack_3_13_2_0_76713.sh'
 ARCHIVE_BASE_HUMANOIDS_59_MD5='ae7cc19055d5cdcad0642008cb75bd93'
@@ -203,11 +214,16 @@ ARCHIVE_BASE_HUMANOIDS_19_VERSION='3.0.3-gog47193'
 
 ## Lithoids
 
+ARCHIVE_BASE_LITHOIDS_49_NAME='stellaris_lithoids_species_pack_3_14_1592653_81105.sh'
+ARCHIVE_BASE_LITHOIDS_49_MD5='61bc2f350ab85060fa192a4ab9d0449f'
+ARCHIVE_BASE_LITHOIDS_49_SIZE='25612'
+ARCHIVE_BASE_LITHOIDS_49_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_LITHOIDS_49_URL='https://www.gog.com/game/stellaris_lithoids_species_pack'
+
 ARCHIVE_BASE_LITHOIDS_48_NAME='stellaris_lithoids_species_pack_3_14_15926_78464.sh'
 ARCHIVE_BASE_LITHOIDS_48_MD5='588c9fe39ff00c406bdb731808c1d43d'
 ARCHIVE_BASE_LITHOIDS_48_SIZE='25612'
 ARCHIVE_BASE_LITHOIDS_48_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_LITHOIDS_48_URL='https://www.gog.com/game/stellaris_lithoids_species_pack'
 
 ARCHIVE_BASE_LITHOIDS_47_NAME='stellaris_lithoids_species_pack_3_13_2_0_76713.sh'
 ARCHIVE_BASE_LITHOIDS_47_MD5='4fba44ef615444494f99af497e4d2b5f'
@@ -281,11 +297,16 @@ ARCHIVE_BASE_LITHOIDS_7_VERSION='3.0.3-gog47193'
 
 ## Necroids
 
+ARCHIVE_BASE_NECROIDS_34_NAME='stellaris_necroids_species_pack_3_14_1592653_81105.sh'
+ARCHIVE_BASE_NECROIDS_34_MD5='5725e03dc497001f9837877ea2beff8d'
+ARCHIVE_BASE_NECROIDS_34_SIZE='24881'
+ARCHIVE_BASE_NECROIDS_34_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_NECROIDS_34_URL='https://www.gog.com/game/stellaris_necroids_species_pack'
+
 ARCHIVE_BASE_NECROIDS_33_NAME='stellaris_necroids_species_pack_3_14_15926_78464.sh'
 ARCHIVE_BASE_NECROIDS_33_MD5='fea1b49566e99f4e1b008c31a85b9bd1'
 ARCHIVE_BASE_NECROIDS_33_SIZE='24881'
 ARCHIVE_BASE_NECROIDS_33_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_NECROIDS_33_URL='https://www.gog.com/game/stellaris_necroids_species_pack'
 
 ARCHIVE_BASE_NECROIDS_32_NAME='stellaris_necroids_species_pack_3_13_2_0_76713.sh'
 ARCHIVE_BASE_NECROIDS_32_MD5='0d3e8d5a8614c7b327584add2c38d13b'
@@ -339,11 +360,16 @@ ARCHIVE_BASE_NECROIDS_2_VERSION='3.4.5-gog56913'
 
 ## Aquatics
 
+ARCHIVE_BASE_AQUATICS_32_NAME='stellaris_aquatics_species_pack_3_14_1592653_81105.sh'
+ARCHIVE_BASE_AQUATICS_32_MD5='1eda07287d1d1fe6bf6cefcf2c142d8e'
+ARCHIVE_BASE_AQUATICS_32_SIZE='29883'
+ARCHIVE_BASE_AQUATICS_32_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_AQUATICS_32_URL='https://www.gog.com/game/stellaris_aquatics_species_pack'
+
 ARCHIVE_BASE_AQUATICS_31_NAME='stellaris_aquatics_species_pack_3_14_15926_78464.sh'
 ARCHIVE_BASE_AQUATICS_31_MD5='9d08da8254187e23fb6334972edd881f'
 ARCHIVE_BASE_AQUATICS_31_SIZE='29883'
 ARCHIVE_BASE_AQUATICS_31_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_AQUATICS_31_URL='https://www.gog.com/game/stellaris_aquatics_species_pack'
 
 ARCHIVE_BASE_AQUATICS_30_NAME='stellaris_aquatics_species_pack_3_13_2_0_76713.sh'
 ARCHIVE_BASE_AQUATICS_30_MD5='fc83fab4aa3748870d373f1fe24f0be3'
@@ -397,11 +423,16 @@ ARCHIVE_BASE_AQUATICS_0_VERSION='3.4.5-gog56913'
 
 ## Toxoids
 
+ARCHIVE_BASE_TOXOIDS_25_NAME='stellaris_toxoids_species_pack_3_14_1592653_81105.sh'
+ARCHIVE_BASE_TOXOIDS_25_MD5='80a09c9500cd8afa5b1a3b0135a64223'
+ARCHIVE_BASE_TOXOIDS_25_SIZE='21991'
+ARCHIVE_BASE_TOXOIDS_25_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_TOXOIDS_25_URL='https://www.gog.com/game/stellaris_toxoids_species_pack'
+
 ARCHIVE_BASE_TOXOIDS_24_NAME='stellaris_toxoids_species_pack_3_14_15926_78464.sh'
 ARCHIVE_BASE_TOXOIDS_24_MD5='eb217db0b1389b6e62e228fe216391ed'
 ARCHIVE_BASE_TOXOIDS_24_SIZE='21991'
 ARCHIVE_BASE_TOXOIDS_24_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_TOXOIDS_24_URL='https://www.gog.com/game/stellaris_toxoids_species_pack'
 
 ARCHIVE_BASE_TOXOIDS_23_NAME='stellaris_toxoids_species_pack_3_13_2_0_76713.sh'
 ARCHIVE_BASE_TOXOIDS_23_MD5='a201f70c2f26f9945459e0a9db4a3ea6'
