@@ -10,11 +10,12 @@ set -o errexit
 # - Distant Stars
 # - Ancient Relics
 # - First Contact
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241215.1
+script_version=20250504.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='stellaris'
 GAME_NAME='Stellaris'
@@ -38,11 +39,16 @@ EXPANSION_NAME_FIRSTCONTACT='First Contact Story Pack'
 
 ## Leviathans
 
+ARCHIVE_BASE_LEVIATHANS_61_NAME='stellaris_leviathans_story_pack_3_14_1592653_81105.sh'
+ARCHIVE_BASE_LEVIATHANS_61_MD5='9c18773594ff2456258e6b6716311b20'
+ARCHIVE_BASE_LEVIATHANS_61_SIZE='58426'
+ARCHIVE_BASE_LEVIATHANS_61_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_LEVIATHANS_61_URL='https://www.gog.com/game/stellaris_leviathans_story_pack'
+
 ARCHIVE_BASE_LEVIATHANS_60_NAME='stellaris_leviathans_story_pack_3_14_15926_78464.sh'
 ARCHIVE_BASE_LEVIATHANS_60_MD5='ae80f10988cea54f567a8d9bbc34b6d9'
 ARCHIVE_BASE_LEVIATHANS_60_SIZE='58426'
 ARCHIVE_BASE_LEVIATHANS_60_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_LEVIATHANS_60_URL='https://www.gog.com/game/stellaris_leviathans_story_pack'
 
 ARCHIVE_BASE_LEVIATHANS_59_NAME='stellaris_leviathans_story_pack_3_13_2_0_76713.sh'
 ARCHIVE_BASE_LEVIATHANS_59_MD5='07773ecc28478515fc25fd000941fd38'
@@ -116,11 +122,16 @@ ARCHIVE_BASE_LEVIATHANS_19_VERSION='3.0.3-gog47193'
 
 ## Synthetic Dawn
 
+ARCHIVE_BASE_SYNTHETICDAWN_60_NAME='stellaris_synthetic_dawn_story_pack_3_14_1592653_81105.sh'
+ARCHIVE_BASE_SYNTHETICDAWN_60_MD5='8da0b258eb5e670ecc758dc938e97878'
+ARCHIVE_BASE_SYNTHETICDAWN_60_SIZE='48245'
+ARCHIVE_BASE_SYNTHETICDAWN_60_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_SYNTHETICDAWN_60_URL='https://www.gog.com/game/stellaris_synthetic_dawn_story_pack'
+
 ARCHIVE_BASE_SYNTHETICDAWN_59_NAME='stellaris_synthetic_dawn_story_pack_3_14_15926_78464.sh'
 ARCHIVE_BASE_SYNTHETICDAWN_59_MD5='6f0eed28ff1d4ed3e0ca8a0470e04b8a'
 ARCHIVE_BASE_SYNTHETICDAWN_59_SIZE='48245'
 ARCHIVE_BASE_SYNTHETICDAWN_59_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_SYNTHETICDAWN_59_URL='https://www.gog.com/game/stellaris_synthetic_dawn_story_pack'
 
 ARCHIVE_BASE_SYNTHETICDAWN_58_NAME='stellaris_synthetic_dawn_story_pack_3_13_2_0_76713.sh'
 ARCHIVE_BASE_SYNTHETICDAWN_58_MD5='2d9bc46f1afe830229ac56b7800a1aba'
@@ -194,11 +205,16 @@ ARCHIVE_BASE_SYNTHETICDAWN_18_VERSION='3.0.3-gog47193'
 
 ## Distant Stars
 
+ARCHIVE_BASE_DISTANTSTARS_60_NAME='stellaris_distant_stars_story_pack_3_14_1592653_81105.sh'
+ARCHIVE_BASE_DISTANTSTARS_60_MD5='eb6a9ad65dd727662706598256581265'
+ARCHIVE_BASE_DISTANTSTARS_60_SIZE='20832'
+ARCHIVE_BASE_DISTANTSTARS_60_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_DISTANTSTARS_60_URL='https://www.gog.com/game/stellaris_distant_stars_story_pack'
+
 ARCHIVE_BASE_DISTANTSTARS_59_NAME='stellaris_distant_stars_story_pack_3_14_15926_78464.sh'
 ARCHIVE_BASE_DISTANTSTARS_59_MD5='1249e6a985f8cd62ecfa37a27b14e877'
 ARCHIVE_BASE_DISTANTSTARS_59_SIZE='20832'
 ARCHIVE_BASE_DISTANTSTARS_59_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_DISTANTSTARS_59_URL='https://www.gog.com/game/stellaris_distant_stars_story_pack'
 
 ARCHIVE_BASE_DISTANTSTARS_58_NAME='stellaris_distant_stars_story_pack_3_13_2_0_76713.sh'
 ARCHIVE_BASE_DISTANTSTARS_58_MD5='ee7f70b07d50956b05d0eb64ae752222'
@@ -272,11 +288,16 @@ ARCHIVE_BASE_DISTANTSTARS_18_VERSION='3.0.3-gog47193'
 
 ## Ancient Relics
 
+ARCHIVE_BASE_ANCIENTRELICS_49_NAME='stellaris_ancient_relics_3_14_1592653_81105.sh'
+ARCHIVE_BASE_ANCIENTRELICS_49_MD5='2ee7c8d5cb9e6d14af6ea68e269960e6'
+ARCHIVE_BASE_ANCIENTRELICS_49_SIZE='32739'
+ARCHIVE_BASE_ANCIENTRELICS_49_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_ANCIENTRELICS_49_URL='https://www.gog.com/game/stellaris_ancient_relics_story_pack'
+
 ARCHIVE_BASE_ANCIENTRELICS_48_NAME='stellaris_ancient_relics_3_14_15926_78464.sh'
 ARCHIVE_BASE_ANCIENTRELICS_48_MD5='df19c65b00fa9fe93f07bd78896a7840'
 ARCHIVE_BASE_ANCIENTRELICS_48_SIZE='32739'
 ARCHIVE_BASE_ANCIENTRELICS_48_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_ANCIENTRELICS_48_URL='https://www.gog.com/game/stellaris_ancient_relics_story_pack'
 
 ARCHIVE_BASE_ANCIENTRELICS_47_NAME='stellaris_ancient_relics_3_13_2_0_76713.sh'
 ARCHIVE_BASE_ANCIENTRELICS_47_MD5='a5154d3b51af853b0c45eeb0685a7f7d'
@@ -350,11 +371,16 @@ ARCHIVE_BASE_ANCIENTRELICS_7_VERSION='3.0.3-gog47193'
 
 ## First Contact
 
+ARCHIVE_BASE_FIRSTCONTACT_23_NAME='stellaris_first_contact_story_pack_3_14_1592653_81105.sh'
+ARCHIVE_BASE_FIRSTCONTACT_23_MD5='08a96e2468e6bf4530ea0a9dc966efe4'
+ARCHIVE_BASE_FIRSTCONTACT_23_SIZE='832'
+ARCHIVE_BASE_FIRSTCONTACT_23_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_FIRSTCONTACT_23_URL='https://www.gog.com/game/stellaris_first_contact_story_pack'
+
 ARCHIVE_BASE_FIRSTCONTACT_22_NAME='stellaris_first_contact_story_pack_3_14_15926_78464.sh'
 ARCHIVE_BASE_FIRSTCONTACT_22_MD5='b7e4021113960f1ca6a26db56a7d13fb'
 ARCHIVE_BASE_FIRSTCONTACT_22_SIZE='832'
 ARCHIVE_BASE_FIRSTCONTACT_22_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_FIRSTCONTACT_22_URL='https://www.gog.com/game/stellaris_first_contact_story_pack'
 
 ARCHIVE_BASE_FIRSTCONTACT_21_NAME='stellaris_first_contact_story_pack_3_13_2_0_76713.sh'
 ARCHIVE_BASE_FIRSTCONTACT_21_MD5='12877f96dc523f3328a8f8231ebb2d84'
