@@ -13,11 +13,12 @@ set -o errexit
 # - Overlord
 # - Galactic Paragons
 # - The Machine Age
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241215.1
+script_version=20250504.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='stellaris'
 GAME_NAME='Stellaris'
@@ -50,11 +51,16 @@ EXPANSION_NAME_MACHINE='The Machine Age'
 
 ## Utopia
 
+ARCHIVE_BASE_UTOPIA_59_NAME='stellaris_utopia_3_14_1592653_81105.sh'
+ARCHIVE_BASE_UTOPIA_59_MD5='ce44b8d0f9afa3e05927c914d1033341'
+ARCHIVE_BASE_UTOPIA_59_SIZE='75007'
+ARCHIVE_BASE_UTOPIA_59_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_UTOPIA_59_URL='https://www.gog.com/game/stellaris_utopia'
+
 ARCHIVE_BASE_UTOPIA_58_NAME='stellaris_utopia_3_14_15926_78464.sh'
 ARCHIVE_BASE_UTOPIA_58_MD5='62b9c4f468f049c1943cfcda6ff8c79e'
 ARCHIVE_BASE_UTOPIA_58_SIZE='75007'
 ARCHIVE_BASE_UTOPIA_58_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_UTOPIA_58_URL='https://www.gog.com/game/stellaris_utopia'
 
 ARCHIVE_BASE_UTOPIA_57_NAME='stellaris_utopia_3_13_2_0_76713.sh'
 ARCHIVE_BASE_UTOPIA_57_MD5='12459f9b139ca756b2c19a5755e41b67'
@@ -128,11 +134,16 @@ ARCHIVE_BASE_UTOPIA_17_VERSION='3.0.3-gog47193'
 
 ## Apocalypse
 
+ARCHIVE_BASE_APOCALYPSE_49_NAME='stellaris_apocalypse_3_14_1592653_81105.sh'
+ARCHIVE_BASE_APOCALYPSE_49_MD5='7f21a52edafc0c8a80e97a947dc5afa6'
+ARCHIVE_BASE_APOCALYPSE_49_SIZE='37877'
+ARCHIVE_BASE_APOCALYPSE_49_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_APOCALYPSE_49_URL='https://www.gog.com/game/stellaris_apocalypse'
+
 ARCHIVE_BASE_APOCALYPSE_48_NAME='stellaris_apocalypse_3_14_15926_78464.sh'
 ARCHIVE_BASE_APOCALYPSE_48_MD5='fe095847b18e9279daca3f2eb407cc2b'
 ARCHIVE_BASE_APOCALYPSE_48_SIZE='37877'
 ARCHIVE_BASE_APOCALYPSE_48_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_APOCALYPSE_48_URL='https://www.gog.com/game/stellaris_apocalypse'
 
 ARCHIVE_BASE_APOCALYPSE_47_NAME='stellaris_apocalypse_3_13_2_0_76713.sh'
 ARCHIVE_BASE_APOCALYPSE_47_MD5='ee89fa59d427166031964f106053fd39'
@@ -206,11 +217,16 @@ ARCHIVE_BASE_APOCALYPSE_7_VERSION='3.0.3-gog47193'
 
 ## MegaCorp
 
+ARCHIVE_BASE_MEGACORP_46_NAME='stellaris_megacorp_3_14_1592653_81105.sh'
+ARCHIVE_BASE_MEGACORP_46_MD5='897bda9d1e5eda534a4913245e3af69b'
+ARCHIVE_BASE_MEGACORP_46_SIZE='90404'
+ARCHIVE_BASE_MEGACORP_46_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_MEGACORP_46_URL='https://www.gog.com/game/stellaris_megacorp'
+
 ARCHIVE_BASE_MEGACORP_45_NAME='stellaris_megacorp_3_14_15926_78464.sh'
 ARCHIVE_BASE_MEGACORP_45_MD5='a16aec518e86ad716206899230871099'
 ARCHIVE_BASE_MEGACORP_45_SIZE='90404'
 ARCHIVE_BASE_MEGACORP_45_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_MEGACORP_45_URL='https://www.gog.com/game/stellaris_megacorp'
 
 ARCHIVE_BASE_MEGACORP_44_NAME='stellaris_megacorp_3_13_2_0_76713.sh'
 ARCHIVE_BASE_MEGACORP_44_MD5='e6b76bb98c26ec597e3a37b3aa915f46'
@@ -284,11 +300,16 @@ ARCHIVE_BASE_MEGACORP_4_VERSION='3.0.3-gog47193'
 
 ## Federations
 
+ARCHIVE_BASE_FEDERATIONS_41_NAME='stellaris_federations_3_14_1592653_81105.sh'
+ARCHIVE_BASE_FEDERATIONS_41_MD5='ce2828f957f35b1ce114c1bf66fa65c2'
+ARCHIVE_BASE_FEDERATIONS_41_SIZE='14433'
+ARCHIVE_BASE_FEDERATIONS_41_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_FEDERATIONS_41_URL='https://www.gog.com/game/stellaris_federations'
+
 ARCHIVE_BASE_FEDERATIONS_40_NAME='stellaris_federations_3_14_15926_78464.sh'
 ARCHIVE_BASE_FEDERATIONS_40_MD5='11fb43cc5b19aebd6bbece34c75492c5'
 ARCHIVE_BASE_FEDERATIONS_40_SIZE='14433'
 ARCHIVE_BASE_FEDERATIONS_40_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_FEDERATIONS_40_URL='https://www.gog.com/game/stellaris_federations'
 
 ARCHIVE_BASE_FEDERATIONS_39_NAME='stellaris_federations_3_13_2_0_76713.sh'
 ARCHIVE_BASE_FEDERATIONS_39_MD5='48ff77ab8c028f6088a0c6743da2bbed'
@@ -352,11 +373,16 @@ ARCHIVE_BASE_FEDERATIONS_1_VERSION='3.2.2-gog51685'
 
 ## Nemesis
 
+ARCHIVE_BASE_NEMESIS_28_NAME='stellaris_nemesis_3_14_1592653_81105.sh'
+ARCHIVE_BASE_NEMESIS_28_MD5='7d686008bc3b604c55578cb7b72b711b'
+ARCHIVE_BASE_NEMESIS_28_SIZE='38539'
+ARCHIVE_BASE_NEMESIS_28_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_NEMESIS_28_URL='https://www.gog.com/game/stellaris_nemesis'
+
 ARCHIVE_BASE_NEMESIS_27_NAME='stellaris_nemesis_3_14_15926_78464.sh'
 ARCHIVE_BASE_NEMESIS_27_MD5='d950bf759ba6311143b1be3ec6811fd7'
 ARCHIVE_BASE_NEMESIS_27_SIZE='38539'
 ARCHIVE_BASE_NEMESIS_27_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_NEMESIS_27_URL='https://www.gog.com/game/stellaris_nemesis'
 
 ARCHIVE_BASE_NEMESIS_26_NAME='stellaris_nemesis_3_13_2_0_76713.sh'
 ARCHIVE_BASE_NEMESIS_26_MD5='3ab5141b829c7747c4622b92789fbe43'
@@ -400,11 +426,16 @@ ARCHIVE_BASE_NEMESIS_0_VERSION='3.6.1-gog60754'
 
 ## Overlord
 
+ARCHIVE_BASE_OVERLORD_23_NAME='stellaris_overlord_3_14_1592653_81105.sh'
+ARCHIVE_BASE_OVERLORD_23_MD5='b556024c88c3d9dec03c8e5945de49b4'
+ARCHIVE_BASE_OVERLORD_23_SIZE='99860'
+ARCHIVE_BASE_OVERLORD_23_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_OVERLORD_23_URL='https://www.gog.com/game/stellaris_overlord'
+
 ARCHIVE_BASE_OVERLORD_22_NAME='stellaris_overlord_3_14_15926_78464.sh'
 ARCHIVE_BASE_OVERLORD_22_MD5='cbc6247838f41c5d8f78c6fb6dba8ac4'
 ARCHIVE_BASE_OVERLORD_22_SIZE='99860'
 ARCHIVE_BASE_OVERLORD_22_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_OVERLORD_22_URL='https://www.gog.com/game/stellaris_overlord'
 
 ARCHIVE_BASE_OVERLORD_21_NAME='stellaris_overlord_3_13_2_0_76713.sh'
 ARCHIVE_BASE_OVERLORD_21_MD5='dbf1a321e0fe23a463030e436dafcda2'
@@ -438,11 +469,16 @@ ARCHIVE_BASE_OVERLORD_2_VERSION='3.8.4.1-gog65337'
 
 ## Galactic Paragons
 
+ARCHIVE_BASE_PARAGONS_23_NAME='stellaris_galactic_paragons_3_14_1592653_81105.sh'
+ARCHIVE_BASE_PARAGONS_23_MD5='b3a00f45cec93aea1ff6a2a0108935a5'
+ARCHIVE_BASE_PARAGONS_23_SIZE='832'
+ARCHIVE_BASE_PARAGONS_23_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_PARAGONS_23_URL='https://www.gog.com/game/stellaris_galactic_paragons'
+
 ARCHIVE_BASE_PARAGONS_22_NAME='stellaris_galactic_paragons_3_14_15926_78464.sh'
 ARCHIVE_BASE_PARAGONS_22_MD5='fd01b388fa76e46e8739a70d26c682f0'
 ARCHIVE_BASE_PARAGONS_22_SIZE='832'
 ARCHIVE_BASE_PARAGONS_22_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_PARAGONS_22_URL='https://www.gog.com/game/stellaris_galactic_paragons'
 
 ARCHIVE_BASE_PARAGONS_21_NAME='stellaris_galactic_paragons_3_13_2_0_76713.sh'
 ARCHIVE_BASE_PARAGONS_21_MD5='ce85a2dffe8e2f5dc5fd691622d96518'
@@ -476,11 +512,16 @@ ARCHIVE_BASE_PARAGONS_2_VERSION='3.8.4.1-gog65337'
 
 ## The Machine Age
 
+ARCHIVE_BASE_MACHINE_8_NAME='stellaris_the_machine_age_3_14_1592653_81105.sh'
+ARCHIVE_BASE_MACHINE_8_MD5='07b714aa18a9c9ff40f5fbf03cf59e2d'
+ARCHIVE_BASE_MACHINE_8_SIZE='100390'
+ARCHIVE_BASE_MACHINE_8_VERSION='3.14.1592653-gog81105'
+ARCHIVE_BASE_MACHINE_8_URL='https://www.gog.com/game/stellaris_the_machine_age'
+
 ARCHIVE_BASE_MACHINE_7_NAME='stellaris_the_machine_age_3_14_15926_78464.sh'
 ARCHIVE_BASE_MACHINE_7_MD5='ab74106e42a9b5525ae852ca27b7020f'
 ARCHIVE_BASE_MACHINE_7_SIZE='100390'
 ARCHIVE_BASE_MACHINE_7_VERSION='3.14.15926-gog78464'
-ARCHIVE_BASE_MACHINE_7_URL='https://www.gog.com/game/stellaris_the_machine_age'
 
 ARCHIVE_BASE_MACHINE_6_NAME='stellaris_the_machine_age_3_13_2_0_76713.sh'
 ARCHIVE_BASE_MACHINE_6_MD5='113ee29d7d37fc5de99f1716114a12f3'
