@@ -5,11 +5,12 @@ set -o errexit
 
 ###
 # The Settlers 2
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241027.1
+script_version=20250722.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='the-settlers-2'
 GAME_NAME='The Settlers Ⅱ'
@@ -157,8 +158,7 @@ GFX
 SAVE
 WORLDS'
 
-GAME_IMAGE='SETTLERS2.INS'
-GAME_IMAGE_TYPE='iso'
+DOSBOX_DISK_IMAGE_PATH='SETTLERS2.INS'
 
 APP_MAIN_EXE='S2.EXE'
 APP_MAIN_ICON='APP/GOGGAME-1207658786.ICO'
@@ -235,16 +235,16 @@ archive_extraction_default
 	## Convert all file paths to uppercase.
 	toupper .
 
-	## Enforce disk image name.
+	## Enforce consistent name for the disk image table of content.
 	if [ -e 'SETTLERS2.INST' ]; then
-		mv 'SETTLERS2.INST' "$GAME_IMAGE"
+		mv 'SETTLERS2.INST' "$(dosbox_disk_image_path)"
 	fi
 
 	## Ensure case consistency in disk image table of contents.
 	sed_pattern='settlers2.gog'
 	sed_replacement='SETTLERS2.GOG'
 	sed_expression="s/${sed_pattern}/${sed_replacement}/i"
-	sed --in-place --expression="$sed_expression" "$GAME_IMAGE"
+	sed --in-place --expression="$sed_expression" "$(dosbox_disk_image_path)"
 
 	## Enforce icon name and path.
 	for icon_path in \
