@@ -6,11 +6,12 @@ set -o errexit
 
 ###
 # Vampire: The Masquerade - Bloodlines
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250223.1
+script_version=20250721.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='vampire-the-masquerade-bloodlines'
 GAME_NAME='Vampire: The Masquerade - Bloodlines'
@@ -132,6 +133,10 @@ vampire.exe
 vampire.exe.12
 dbghelp.dll
 loader.dll'
+## This configuration file is created by the current game script,
+## cf. "Give access to character histories (backgrounds)"
+CONTENT_GAME0_BIN_FILES='
+vampire/cfg/config.cfg'
 ## These paths are created at the "Extract game data" step.
 CONTENT_GAME_L10N_EN_PATH_DOTEMU='l10n-en'
 CONTENT_GAME_L10N_FR_PATH_DOTEMU='l10n-fr'
@@ -190,7 +195,7 @@ APP_MAIN_EXE_DOTEMU='vampire.exe'
 APP_MAIN_EXE_GOG='loader.exe'
 APP_MAIN_ICON='vampire.exe'
 ## Work around the deletion of zlib1.dll
-## TODO: Check if it is still required with current WINE
+## (WINE 10.0)
 APP_MAIN_PRERUN='
 # Work around the deletion of zlib1.dll
 system_library="${WINEPREFIX}/drive_c/windows/system32/zlib1.dll"
@@ -198,32 +203,13 @@ if [ ! -e "$system_library" ]; then
 	cp "bin/zlib1.dll" "$system_library"
 fi
 '
-## Switch French keyboard layout to us-azerty to provide direct access to digits.
-## TODO: Update this snippet to make it work on Wayland too.
-APP_MAIN_PRERUN="${APP_MAIN_PRERUN:-}"'
-# Switch French keyboard layout to us-azerty to provide direct access to digits.
-# This is required to not get stuck when asked to type digits in-game.
-## This works on X.org only, not on Wayland.
-if [ -z "${WAYLAND_DISPLAY:-}" ] && [ -n "${DISPLAY:-}" ] && command -v setxkbmap >/dev/null 2>&1; then
-	KEYBOARD_RESTORE_VARIANT=0
-	KEYBOARD_LAYOUT=$(LANG=C setxkbmap -query | awk "/layout:/ {print \$2}")
-	if [ "$KEYBOARD_LAYOUT" = "fr" ]; then
-		KEYBOARD_VARIANT=$(LANG=C setxkbmap -query | awk "/variant:/ {print \$2}")
-		if [ "$KEYBOARD_VARIANT" != "us-azerty" ]; then
-			KEYBOARD_RESTORE_VARIANT=1
-			setxkbmap -variant us-azerty
-		fi
-	fi
-fi
-'
+## Keep hold of the terminal until the game process actually ends,
+## instead of returning as soon as the game is started
 APP_MAIN_POSTRUN='
-# Restore the keyboard variant, if it has previously been switched to us-azerty.
-## This works on X.org only, not on Wayland.
-if [ -z "${WAYLAND_DISPLAY:-}" ] && [ -n "${DISPLAY:-}" ] && command -v setxkbmap >/dev/null 2>&1; then
-	if [ $KEYBOARD_RESTORE_VARIANT -eq 1 ]; then
-		setxkbmap -variant "$KEYBOARD_VARIANT"
-	fi
-fi
+# Keep hold of the terminal until the game process actually ends,
+# instead of returning as soon as the game is started
+sleep 10s
+pidwait --euid "$USER" --ignore-case vampire.exe
 '
 
 PACKAGES_LIST_DOTEMU='
@@ -244,14 +230,14 @@ PKG_BIN_ARCH='32'
 PKG_BIN_DEPENDENCIES_SIBLINGS='
 PKG_L10N_BASE
 PKG_DATA'
+PKG_BIN_DEPENDENCIES_COMMANDS='
+pidwait'
 
 PKG_L10N_BASE_ID="${GAME_ID}-l10n"
 PKG_L10N_EN_ID="${PKG_L10N_BASE_ID}-en"
 PKG_L10N_FR_ID="${PKG_L10N_BASE_ID}-fr"
 PKG_L10N_PROVIDES="
 $PKG_L10N_BASE_ID"
-PKG_L10N_EN_PROVIDES="$PKG_L10N_PROVIDES"
-PKG_L10N_FR_PROVIDES="$PKG_L10N_PROVIDES"
 PKG_L10N_EN_ENSCRIPTION='English localization'
 PKG_L10N_FR_FRSCRIPTION='French localization'
 
@@ -356,6 +342,13 @@ archive_extraction_default
 			tolower .
 		;;
 	esac
+
+	# Give access to character histories (backgrounds).
+	config_file='vampire/cfg/config.cfg'
+	mkdir --parents "$(dirname "$config_file")"
+	cat > "$config_file" <<- EOF
+	vchar_edit_histories "1"
+	EOF
 )
 
 # Include game data
