@@ -8,9 +8,10 @@ set -o errexit
 # - My Pet Dungeon
 # - Heart of Gold
 # - The Under Games
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250103.1
+script_version=20250427.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
@@ -30,11 +31,16 @@ EXPANSION_NAME_UNDERGAMES='The Under Games'
 
 ## My Pet Dungeon
 
+ARCHIVE_BASE_PETDUNGEON_8_NAME='war_for_the_overworld_my_pet_dungeon_v2_1_3_81115.sh'
+ARCHIVE_BASE_PETDUNGEON_8_MD5='31070753b7800ecce32b82ed5582fad7'
+ARCHIVE_BASE_PETDUNGEON_8_SIZE='1048'
+ARCHIVE_BASE_PETDUNGEON_8_VERSION='2.1.3-gog81115'
+ARCHIVE_BASE_PETDUNGEON_8_URL='https://www.gog.com/game/war_for_the_overworld_my_pet_dungeon'
+
 ARCHIVE_BASE_PETDUNGEON_7_NAME='war_for_the_overworld_my_pet_dungeon_v2_1_2_76431.sh'
 ARCHIVE_BASE_PETDUNGEON_7_MD5='4561b9cb3f6405c7c576da87e9e74175'
 ARCHIVE_BASE_PETDUNGEON_7_SIZE='1048'
 ARCHIVE_BASE_PETDUNGEON_7_VERSION='2.1.2-gog76431'
-ARCHIVE_BASE_PETDUNGEON_7_URL='https://www.gog.com/game/war_for_the_overworld_my_pet_dungeon'
 
 ARCHIVE_BASE_PETDUNGEON_6_NAME='war_for_the_overworld_my_pet_dungeon_v2_1_1_73576.sh'
 ARCHIVE_BASE_PETDUNGEON_6_MD5='435ec9378fbefad46ad4827d870b84e1'
@@ -68,11 +74,16 @@ ARCHIVE_BASE_PETDUNGEON_1_VERSION='2.0.5-gog24177'
 
 ## Heart of Gold
 
+ARCHIVE_BASE_HEARTOFGOLD_5_NAME='war_for_the_overworld_heart_of_gold_v2_1_3_81115.sh'
+ARCHIVE_BASE_HEARTOFGOLD_5_MD5='2b1629d133d9c9291e4d7ab3e7ae82c0'
+ARCHIVE_BASE_HEARTOFGOLD_5_SIZE='1048'
+ARCHIVE_BASE_HEARTOFGOLD_5_VERSION='2.1.3-gog81115'
+ARCHIVE_BASE_HEARTOFGOLD_5_URL='https://www.gog.com/game/war_for_the_overworld_heart_of_gold'
+
 ARCHIVE_BASE_HEARTOFGOLD_4_NAME='war_for_the_overworld_heart_of_gold_v2_1_2_76431.sh'
 ARCHIVE_BASE_HEARTOFGOLD_4_MD5='c3acb781eda622962857b70416fc7a54'
 ARCHIVE_BASE_HEARTOFGOLD_4_SIZE='1048'
 ARCHIVE_BASE_HEARTOFGOLD_4_VERSION='2.1.2-gog76431'
-ARCHIVE_BASE_HEARTOFGOLD_4_URL='https://www.gog.com/game/war_for_the_overworld_heart_of_gold'
 
 ARCHIVE_BASE_HEARTOFGOLD_3_NAME='war_for_the_overworld_heart_of_gold_v2_1_1_73576.sh'
 ARCHIVE_BASE_HEARTOFGOLD_3_MD5='653ab69838583a231b7cc8128286e183'
@@ -96,11 +107,16 @@ ARCHIVE_BASE_HEARTOFGOLD_0_VERSION='2.0.6f1-gog30014'
 
 ## The Under Games
 
+ARCHIVE_BASE_UNDERGAMES_4_NAME='war_for_the_overworld_the_under_games_v2_1_3_81115.sh'
+ARCHIVE_BASE_UNDERGAMES_4_MD5='d408718a67271601c0d3b57ccc5c07a7'
+ARCHIVE_BASE_UNDERGAMES_4_SIZE='1048'
+ARCHIVE_BASE_UNDERGAMES_4_VERSION='2.1.3-gog81115'
+ARCHIVE_BASE_UNDERGAMES_4_URL='https://www.gog.com/game/war_for_the_overworld_the_under_games'
+
 ARCHIVE_BASE_UNDERGAMES_3_NAME='war_for_the_overworld_the_under_games_v2_1_2_76431.sh'
 ARCHIVE_BASE_UNDERGAMES_3_MD5='09378c271fee3fd4eac40d14f6161831'
 ARCHIVE_BASE_UNDERGAMES_3_SIZE='1048'
 ARCHIVE_BASE_UNDERGAMES_3_VERSION='2.1.2-gog76431'
-ARCHIVE_BASE_UNDERGAMES_3_URL='https://www.gog.com/game/war_for_the_overworld_the_under_games'
 
 ARCHIVE_BASE_UNDERGAMES_2_NAME='war_for_the_overworld_the_under_games_v2_1_1_73576.sh'
 ARCHIVE_BASE_UNDERGAMES_2_MD5='820594211c64b3fe94716921c1da3f73'
