@@ -5,20 +5,26 @@ set -o errexit
 
 ###
 # War for the Overworld
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250103.1
+script_version=20250427.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='war-for-the-overworld'
 GAME_NAME='War for the Overworld'
 
+ARCHIVE_BASE_9_NAME='war_for_the_overworld_v2_1_3_81115.sh'
+ARCHIVE_BASE_9_MD5='1b18aa35479357a3ecb02d8763935705'
+ARCHIVE_BASE_9_SIZE='5085906'
+ARCHIVE_BASE_9_VERSION='2.1.3-gog81115'
+ARCHIVE_BASE_9_URL='https://www.gog.com/game/war_for_the_overworld'
+
 ARCHIVE_BASE_8_NAME='war_for_the_overworld_v2_1_2_76431.sh'
 ARCHIVE_BASE_8_MD5='e834b2a81bff0a36dc50fcf7a061abec'
 ARCHIVE_BASE_8_SIZE='4814079'
 ARCHIVE_BASE_8_VERSION='2.1.2-gog76431'
-ARCHIVE_BASE_8_URL='https://www.gog.com/game/war_for_the_overworld'
 
 ARCHIVE_BASE_7_NAME='war_for_the_overworld_v2_1_1_73576.sh'
 ARCHIVE_BASE_7_MD5='d3095d210fda9c39cd2cec6c2d0a882f'
